﻿local addonName, QD = ...; -- gets addon-local variables

local L = QD.LOCALIZATION;

----------------------------------------------------------------------------------------------------
-- Slash commands

SlashCmdList['QUIDICIT_SLASHCMD'] = function( msg, ... )
    local command, args = msg:match("^(%S*)%s*(.-)$");

    command = strlower(command);
    local untrimmed = args;
    args = strtrim(args);

    ---------------------
    -- Main Commands
    if ( command == "on" ) then
        -- activates coloring
        QD.Core_ToggleOnOff(true, true);

    elseif ( command == "off" ) then
        -- disables coloring
        QD.Core_ToggleOnOff(false, true);

    elseif ( command == "colornames" ) then
        if ( args == "on" or args == "true" or args=="1" ) then
            QD.Core_ToggleNames( true, true );
        else
            QD.Core_ToggleNames( false, true );
        end
    elseif ( command == "colorlines" ) then
        if ( args == "on" or args == "true" or args=="1") then
            QD.Core_ToggleLines( true, true );
        else
            QD.Core_ToggleLines( false, true );
        end

    elseif ( command == "pretext" ) then
        args = strsub(args, 2,-2);
        QD.Core_SetPretext(args, true);

    elseif ( command == "posttext" ) then
        args = strsub(args, 2,-2);
        QD.Core_SetPosttext(args, true);

    elseif ( command == "priority" ) then
        QD.Core_SetPriority(args, true);

    elseif ( command == "showconfig" ) then
        QD.Core_PrintConfig();

    elseif ( command == "showcolors" ) then
        QD.Core_PrintColors();

    elseif ( command == "channel" ) then
        local channelname, state = args:match("^(%S*)%s*(.-)$");
        channelname = strupper(channelname);
        if ( state == "on" or state == "true" or state == "1" ) then
            state = true;
        else
            state = false;
        end
        QD.ChatChannel_ToggleChannel ( channelname, state, true )


    elseif ( command == "charcolor" or command == "cc") then
        -- adds a user with individual color
        local character = strsub(args, 0, -8);
        local color = strsub(args, -6);
        QD.Character_ChangeColor(character, color);
        QD.printInfo(addonName .. ": \124cFF"..color..character .."\124r ".. L.info.MSG_COLORED .. ".");

    elseif ( command == "chargroup" or command == "cg") then
        -- adds a user with individual color
        local character,group = args:match("^(%S*)%s*(.-)$");
        QD.Character_ChangeGroup(character, group);
        QD.printInfo(addonName .. ": " .. character .. " " ..L.info.MSG_CHANGE_GROUP .. " " .. group .. ".");

    elseif ( command == "removecharcolor" or command == "rcc") then
        -- removes an individual color (character)
        QD.Character_ResetColor( args );
        QD.printInfo(addonName .. ": " .. args .. " " .. L.info.MSG_RESET_COLOR);

    elseif ( command == "removechargroup" or command == "rcg") then
        -- removes the group from a character
        QD.Character_ResetGroup( args );
        QD.printInfo(addonName .. ": " .. args .. " " .. L.info.MSG_RESET_GROUP);

    elseif ( command == "removechar" or command == "rc") then
        -- removes an removes a character
        QD.Character_Remove( args );
        QD.printInfo(addonName .. ": ".. args .. " ".. L.info.MSG_REMOVED_VI);

    elseif ( command == "removeallchars" ) then
        QD.Character_RemoveAll();
        QD.printInfo(addonName .. ": "..L.info.MSG_CHARREMOVEALL .. ".");


    elseif ( command == "groupcolor" or command == "gc") then
        -- changes group coloring
        local group = strsub(args, 0, -8);
        local color = strsub(args, -6);
        QD.Group_ChangeColor(group, color);
        QD.printInfo(addonName .. ": \124cFF"..color..group .."\124r ".. L.info.MSG_COLORED .. ".");

    elseif ( command == "removegroup" or command == "rg") then
        -- removes an removes a group
        QD.Group_Remove( args );
        QD.printInfo(addonName .. ": ".. args .." ".. L.info.MSG_REMOVED_VI);

    elseif ( command == "removeallgroups" ) then
        QD.Group_RemoveAll();
        QD.printInfo(addonName .. ": "..L.info.MSG_GROUPREMOVEALL .. ".");


    ---------------------
    -- help commands
    elseif ( command == "help" ) then
        -- prints possible commands
        local col1 = QD.colors.chatcommand;

        QD.printInfo(addonName .. " ".. L.help.MSG_CMD .. ":");
        QD.printInfo(col1.."    /quidicit, /qdic, /qd  |r");
        QD.printInfo(col1.."    /qdic help  |r" .. L.help.MSG_HELP .. "");
        QD.printInfo(col1.."    /qdic on  |r" .. L.help.MSG_ACTIVATE .. " " .. addonName);
        QD.printInfo(col1.."    /qdic off  |r" .. L.help.MSG_DEACTIVATE .. " " .. addonName);
        QD.printInfo(col1.."    /qdic showconfig  |r" .. L.help.MSG_SHOWCONFIG);
        QD.printInfo(col1.."    /qdic showcolors  |r" .. L.help.MSG_SHOWCOLORS);
        QD.printInfo(col1.."    /qdic colornames on/off  |r" .. L.help.MSG_COLORNAMES);
        QD.printInfo(col1.."    /qdic colorlines on/off  |r" .. L.help.MSG_COLORLINES);
        QD.printInfo(col1.."    /qdic channel chan on/off  |r" .. L.help.MSG_CHANNELS);
        QD.printInfo(col1.."    /qdic pretext \"text\"  |r" .. L.help.MSG_PRETEXT);
        QD.printInfo(col1.."    /qdic posttext \"text\"  |r" .. L.help.MSG_POSTTEXT);
        QD.printInfo(col1.."    /qdic priority name/group  |r" .. L.help.MSG_PRIORITY);


        QD.printInfo(" ");
        QD.printInfo(addonName .. " ".. L.help.MSG_CMD .. " "..L.CHARNAME..":");
        QD.printInfo(col1.."    /qdic usercolor character rrggbb |r" .. L.help.MSG_USERCOLOR .. " ");
        QD.printInfo(col1.."    /qdic usergroup  character group |r" .. L.help.MSG_USERGROUP .. " ");
        QD.printInfo(col1.."    /qdic removecharcolor character |r" .. L.help.MSG_REM_CHARCOLOR .. " ");
        QD.printInfo(col1.."    /qdic removechargroup character |r" .. L.help.MSG_REM_CHARGROUP .. " ");
        QD.printInfo(col1.."    /qdic removechar character |r" .. L.help.MSG_REM_CHAR .. " ");
        QD.printInfo(col1.."    /qdic removeallchars |r" .. L.help.MSG_CHARREMOVEALL .. " ");

        QD.printInfo(" ");
        QD.printInfo(addonName .. " ".. L.help.MSG_CMD .. " "..L.GROUPNAME..":");
        QD.printInfo(col1.."    /qdic groupcolor group rrggbb |r" .. L.help.MSG_GROUPCOLOR .. " ");
        QD.printInfo(col1.."    /qdic removegroup group |r" .. L.help.MSG_REM_GROUP .. " ");
        QD.printInfo(col1.."    /qdic removegroup group |r" .. L.help.MSG_REM_GROUP .. " ");
        QD.printInfo(col1.."    /qdic removeallgroups |r" .. L.help.MSG_GROUPREMOVEALL .. " ");

        -- QD.printInfo(col1.."    /qdic usercolor  |r" .. " >>TMP<<" .. " ");

    else
        QD.printInfo(L.info.MSG_COMMANDERROR .. QD.colors.chatcommand .. " /qdic help|r");
    end

    QD.Character_Check();
end
SLASH_QUIDICIT_SLASHCMD1 = '/quidicit';
SLASH_QUIDICIT_SLASHCMD2 = '/qdic';
SLASH_QUIDICIT_SLASHCMD3 = '/qd';



----------------------------------------------------------------------------------------------------
-- Slash command functions
