﻿local addonName, QD = ...; -- gets addon-local variables

local L = QD.LOCALIZATION;


----------------------------------------------------------------------------------------------------
-- Core functions

function QD.Core_ToggleOnOff( param, showText )
    if ( param == nil ) then -- toggle
        QD.on = not QD.on;
    else
        QD.on = param;
    end

    if ( showText ) then
        if ( QD.on ) then
            QD.printInfo(addonName .. " " .. L.info.MSG_ACTIVE..".");
        else
            QD.printInfo(addonName .. " " .. L.info.MSG_DEACTIVE .. ".");
        end
    end
end

function QD.Core_ToggleNames( param, showText )
    if ( param == nil ) then -- toggle
        QD.colorNames = not QD.colorNames;
    else
        QD.colorNames = param;
    end

    if ( showText ) then
        if ( QD.colorNames ) then
            QD.printInfo(addonName .. " " .. L.info.MSG_ACTIVENAME..".");
        else
            QD.printInfo(addonName .. " " .. L.info.MSG_INACTIVENAME .. ".");
        end
    end
end

function QD.Core_ToggleLines( param, showText )
    if (param == nil) then -- toggle
        QD.colorLines = not QD.colorLines;
    else
        QD.colorLines = param;
    end

    if ( showText ) then
        if ( QD.colorLines ) then
            QD.printInfo(addonName .. " " .. L.info.MSG_ACTIVELINE..".");
        else
            QD.printInfo(addonName .. " " .. L.info.MSG_INACTIVELINE .. ".");
        end
    end
end

function QD.Core_GetOnOffText( param )
    if ( param ) then
        return QD.TEXTON;
    else
        return QD.TEXTOFF;
    end
end

function QD.Core_ColorTextOnOff ( text, param)
    if ( param ) then
        return "|cFF00ce00"..text.."|r";
    else
        return "|cFFce0000"..text.."|r";
    end
end

function QD.Core_PrintConfig()
    QD.printInfo(addonName .. " v"..GetAddOnMetadata(addonName,"Version").." config:");
    QD.printInfo("    " .. QD.Core_GetOnOffText(QD.on) .. " " .. addonName);
    QD.printInfo("    " .. QD.Core_GetOnOffText(QD.colorNames) .. " " .. L.menu.MENU_ONOFFCOLORNAME);
    QD.printInfo("    " .. QD.Core_GetOnOffText(QD.colorLines) .. " " .. L.menu.MENU_ONOFFCOLORLINE);
    QD.printInfo("    \""..QD.preText..GetUnitName("player")..QD.postText.."\"");
    if ( QD.priority == QD.PRIORITY_COLOR_INDIVIDUAL ) then
        QD.printInfo("    " .. L.CHARNAME .. ">"..L.GROUPNAME);
    else
        QD.printInfo("    " .. L.GROUPNAME .. ">"..L.CHARNAME);
    end
    local channels = "";
    for k,v in pairs (QD.usedChannels) do
        channels = channels .. QD.Core_ColorTextOnOff(k,v) .. "  ";
    end
    QD.printInfo("    " .. L.menu.MENU_CHANNELS .. ": " .. channels);
end

function QD.Core_PrintColors()
    QD.Core_PrintColorsChar();
    QD.Core_PrintColorsGroup();
end

function QD.Core_PrintColorsChar()
    local nC = 0; for k,v in pairs (QD.vips) do nC = nC + 1; end
    QD.printInfo("QuiDicit "..L.CHARNAME.." ("..nC.."):");
    for k,v in pairs (QD.vips) do
        local name = ""..tostring(k);

        local color = QD.Color_GetChatColor(name);
        local unit = name;
        if ( color and color ~= "" ) then
            unit = "|cFF" .. color .. name .. "|r";
        end

        if(v.color ~= "") then
            name = "|cFF"..v.color..name.."|r ("..v.color..")";
        end
        local group = ""..tostring(v.group);
        if(QD.vigs[group] and QD.vigs[group] ~= "") then
            group = "|cFF"..QD.vigs[group].color..group.."|r ("..QD.vigs[group].color..")";
        end
        if ( group and group == "" ) then
            group = "-";
        end
        QD.printInfo("    "..unit..":   "..tostring(name)..", " .. tostring(group));
    end
end

function QD.Core_PrintColorsGroup()
    local nG = 0; for k,v in pairs (QD.vigs) do nG = nG + 1; end
    QD.printInfo("QuiDicit "..L.GROUPNAME.." ("..nG.."):");
    for k,v in pairs (QD.vigs) do
        local g = ""..tostring(k);
        if(g.color ~= "") then
            g = "|cFF"..v.color..g.."|r ("..v.color..")";
        end
        QD.printInfo("    "..tostring(g));
    end
end

function QD.Core_SetPretext( text, showText )
    if ( text ) then
        local player = GetUnitName("player");
        QD.preText = text;
        if ( showText ) then
            QD.printInfo(L.info.MSG_TEXTDECO .. ": \""..QD.preText..player..QD.postText.."\"");
        end
    end
end

function QD.Core_SetPosttext( text, showText )
    if ( text ) then
        local player = GetUnitName("player");
        QD.postText = text;
        if ( showText ) then
            QD.printInfo(L.info.MSG_TEXTDECO .. ": \""..QD.preText..player..QD.postText.."\"");
        end
    end
end

function QD.Core_SetPriority( priority, showText )

    local msg = "";
    if ( priority == QD.PRIORITY_COLOR_INDIVIDUAL or priority == "name") then
        QD.priority = QD.PRIORITY_COLOR_INDIVIDUAL;
        msg = L.CHARNAME;
    elseif ( priority == QD.PRIORITY_COLOR_GROUP or priority == "group") then
        QD.priority = QD.PRIORITY_COLOR_GROUP;
        msg = L.GROUPNAME;
    end

    if ( msg ~= "" ) then
        QD.printInfo(addonName .. " " .. L.info.MSG_PRIORITY.." " .. msg);
    end
end

----------------------------------------------------------------------------------------------------
-- Color Management

function QD.Color_GetCharacterColor(character)
    local color = "";
    
    for k,v in pairs(QD.vips) do
        -- find character
        if (k == character or string.find(character, k .. "-") ~= nil) then
            if ( v.color ~= "") then
                -- individual color
                return v.color;
            end
            break;
        end
    end
    return color; -- return value is "" empty string if character color unknown
end

function QD.Color_GetGroupColor( group )
    local color = "";

    for k,v in pairs(QD.vigs) do
        if (k == group) then
            if ( v.color ~= "") then
                -- group color
                return v.color;
            end
            break;
        end;
    end

    return color; -- return value is "" empty string if group color unknown
end

function QD.Color_GetChatColor( character )
     -- individual color
    local colorChar = QD.Color_GetCharacterColor(character);
    if (colorChar ~= "" and QD.priority == QD.PRIORITY_COLOR_INDIVIDUAL) then
        return colorChar;
    end

    -- determine group
    local group = "";
    local characterNameOnly = character;
    if (string.find(character, "-") ~= nil) then
        characterNameOnly = string.sub(character, 1, select(1,string.find(character, "-")-1))
    end
    if (QD.vips[character] ~= nil) then
        group =  QD.vips[character].group; -- set group/guild
    elseif (characterNameOnly and QD.vips[characterNameOnly] ~= nil) then
        group =  QD.vips[characterNameOnly].group; -- set group/guild
    end
    -- -- determine guild
    -- if ( group == "" and QD.autoGuild) then
        -- -- TODO recognize auto guild groups
        -- group,_,_ = GetGuildInfo(character);
        -- -- QD.printDebug("guild = "..tostring(group));
        -- if ( group == nil ) then
            -- group = "";
        -- end
    -- end
    -- QD.printDebug("group = "..group);

     -- group color
    local colorGroup = QD.Color_GetGroupColor( group );
    if (colorGroup ~= "" and QD.priority == QD.PRIORITY_COLOR_GROUP) then
    print("group bevorzugt");
        return colorGroup;
    end


    if (colorChar ~= "" and colorGroup == "" ) then
        return colorChar;
    elseif (colorGroup ~= "" and colorChar == "") then
        return colorGroup;
    end
    return "";
end


----------------------------------------------------------------------------------------------------
-- Character Management

function QD.Character_ChangeColor(user, color)
    if (strfind(user, "-") == nil) then
        user = user .. "-" .. GetRealmName()
    end

    -- check if user already exists
    for k,v in pairs(QD.vips) do
        if ( k == user ) then -- update user
            QD.vips[user].color = color;
            return;
        end
    end

    -- add new user
    QD.vips[user] = {
        color = color,
        group = "",
    }
end

function QD.Character_ChangeGroup(user, group)
    if (strfind(user, "-") == nil) then
        user = user .. "-" .. GetRealmName()
    end
    
    -- check if character already exists
    if ( QD.vips[user] ) then -- character already exists
        QD.vips[user].group = group;
    else -- create new character
        QD.vips[user] = {
            color = "",
            group = group,
        }
    end

    -- check if group exists
    if ( QD.vigs[group] ) then
        -- group already exists
    else
        -- create new group
        QD.vigs[group] = {};
        QD.vigs[group].color = QD.DEFAULT_COLOR;
    end
end

function QD.Character_Remove( character )
    if (strfind(character, "-") == nil) then
        character = character .. "-" .. GetRealmName()
    end
    -- remove character from list if it exists
    if ( QD.vips[character] ) then
        QD.vips[character] = nil;
    end
end

function QD.Character_RemoveAll()
    QD.vips = {};
end

function QD.Character_ResetColor( character )
    if (strfind(character, "-") == nil) then
        character = character .. "-" .. GetRealmName()
    end
    if(QD.vips[character] ~= nil) then
        QD.vips[character].color = "";
    end
end

function QD.Character_ResetGroup( character )
    if (strfind(character, "-") == nil) then
        character = character .. "-" .. GetRealmName()
    end
    if(QD.vips[character] ~= nil) then
        QD.vips[character].group = "";
    end
end

function QD.Character_Check()
    for k,v in pairs(QD.vips) do
        if ( QD.vips[k].color == "" and QD.vips[k].group == "" ) then
            QD.vips[k] = nil;
        end
    end
end


----------------------------------------------------------------------------------------------------
-- Group Management
function QD.Group_ChangeColor(group, color)
    -- check if group already exists
    for k,v in pairs(QD.vigs) do
        if ( k == group ) then -- update group
            QD.vigs[group].color = color;
            return;
        end
    end

    -- add new group
    QD.vigs[group] = {
        color = color,
    }
end

function QD.Group_Clear( group )
    for k,v in pairs(QD.vips) do
        if ( QD.vips[k].group == group ) then
            QD.vips[k].group = "";
        end
    end
end

function QD.Group_Remove( group )
    -- remove group from vips
    for k,v in pairs (QD.vips) do
        if ( v.group == group ) then
            v.group = "";
            break;
        end
    end

    -- remove group itself
    if ( QD.vigs[group] ) then
        QD.vigs[group] = nil;
    end
end

function QD.Group_RemoveAll()
    for k, v in pairs (QD.vigs) do
        QD.Group_Remove( k );
    end
    QD.vigs = {};
end


----------------------------------------------------------------------------------------------------
-- Chat Channel Management

function QD.ChatChannel_IsUsed( channel )
    if     (QD.usedChannels.SAY   and tContains(ChatTypeGroup["SAY"],channel)) then -- SAY
        return true;
    elseif (QD.usedChannels.EMOTE and tContains(ChatTypeGroup["EMOTE"],channel)) then -- EMOTE
        return true;
    elseif (QD.usedChannels.YELL  and tContains(ChatTypeGroup["YELL"],channel)) then -- YELL
        return true;
    elseif (QD.usedChannels.PARTY and tContains(ChatTypeGroup["PARTY"],channel)) then -- PARTY
        return true;
    elseif (QD.usedChannels.PARTY and tContains(ChatTypeGroup["PARTY_LEADER"],channel)) then -- PARTY
        return true;
    elseif (QD.usedChannels.RAID  and tContains(ChatTypeGroup["RAID"],channel)) then -- RAID
        return true;
    elseif (QD.usedChannels.RAID  and tContains(ChatTypeGroup["RAID_LEADER"],channel)) then -- RAID
        return true;
    elseif (QD.usedChannels.RAID  and tContains(ChatTypeGroup["RAID_WARNING"],channel)) then -- RAID
        return true;
    elseif (QD.usedChannels.BATTLEGROUND and tContains(ChatTypeGroup["BATTLEGROUND"],channel)) then -- BATTLEGROUND
        return true;
    elseif (QD.usedChannels.BATTLEGROUND and tContains(ChatTypeGroup["BATTLEGROUND_LEADER"],channel)) then -- BATTLEGROUND
        return true;
    elseif (QD.usedChannels.GUILD and tContains(ChatTypeGroup["GUILD"],channel)) then -- GUILD
        return true;
    elseif (QD.usedChannels.GUILD and tContains(ChatTypeGroup["OFFICER"],channel)) then -- GUILD
        return true;
    else
        return false;
    end
end

function QD.ChatChannel_IsTypeUsed( channelType )
    if ( not ChatTypeInfo[channelType] ) then
        return false;
    end

    if     (QD.usedChannels.SAY   and channelType == "SAY") then -- SAY
        return true;
    elseif (QD.usedChannels.EMOTE and channelType == "EMOTE") then -- EMOTE
        return true;
    elseif (QD.usedChannels.YELL  and channelType == "YELL") then -- YELL
        return true;
    elseif (QD.usedChannels.PARTY and channelType == "PARTY") then -- PARTY
        return true;
    elseif (QD.usedChannels.PARTY and channelType == "PARTY_LEADER") then -- PARTY
        return true;
    elseif (QD.usedChannels.RAID  and channelType == "RAID") then -- RAID
        return true;
    elseif (QD.usedChannels.RAID  and channelType == "RAID_LEADER") then -- RAID
        return true;
    elseif (QD.usedChannels.RAID  and channelType == "RAID_WARNING") then -- RAID
        return true;
    elseif (QD.usedChannels.BATTLEGROUND and channelType == "BATTLEGROUND") then -- BATTLEGROUND
        return true;
    elseif (QD.usedChannels.BATTLEGROUND and channelType == "BATTLEGROUND_LEADER") then -- BATTLEGROUND
        return true;
    elseif (QD.usedChannels.GUILD and channelType == "GUILD") then -- GUILD
        return true;
    elseif (QD.usedChannels.GUILD and channelType == "OFFICER") then -- GUILD
        return true;
    else
        return false;
    end
end

function QD.ChatChannel_ToggleChannel ( channel, active, showtext )
    if ( QD.usedChannels[channel] ~= nil ) then
        if ( active == nil ) then -- toggle
            QD.usedChannels[channel] = not QD.usedChannels[channel];
        else
            QD.usedChannels[channel] = active;
        end

        if ( showtext ) then
            QD.printInfo(addonName .. ": " .. channel .. " " .. QD.Core_GetOnOffText(QD.usedChannels[channel]));
        end
    end
end